@@ -19,7 +19,19 @@ LanguageListModel::LanguageListModel(QObject *parent)
 {
     connect(this, &LanguageListModel::isPreviewExampleChanged, this, &LanguageListModel::exampleChanged);
     connect(m_selectedLanguageModel, &SelectedLanguageModel::exampleChanged, this, &LanguageListModel::exampleChanged);
-    m_availableLanguages = KLocalizedString::availableDomainTranslations("plasmashell").values();
+    /* explicitly set pt to pt_PT as a workaround for GNU Gettext and CLDR treat the default dialect of 'pt' differently
+     *
+     * see https://invent.kde.org/plasma/plasma-workspace/-/merge_requests/2478
+     * and https://mail.kde.org/pipermail/kde-i18n-doc/2023-January/001340.html
+     * for more info on the matter
+     */
+    auto availableLanguages = KLocalizedString::availableDomainTranslations("plasmashell");
+    if (availableLanguages.contains(QStringLiteral("pt"))) {
+        availableLanguages.remove(QStringLiteral("pt"));
+        availableLanguages.insert(QStringLiteral("pt_PT"));
+    }
+
+    m_availableLanguages = availableLanguages.values();
     m_availableLanguages.sort();
     m_availableLanguages.push_front(QStringLiteral("C"));
 }
@@ -155,12 +167,14 @@ QString LanguageListModel::metric() const
     return exampleHelper(Utility::measurementExample);
 }
 
-void LanguageListModel::setRegionAndLangSettings(QObject *settings)
+void LanguageListModel::setRegionAndLangSettings(QObject *settings, QObject *kcm)
 {
-    if (auto *regionandlangsettings = dynamic_cast<RegionAndLangSettings *>(settings)) {
-        m_settings = regionandlangsettings;
-        m_selectedLanguageModel->setRegionAndLangSettings(regionandlangsettings);
-        Q_EMIT exampleChanged();
+    if (auto *regionandlangsettings = qobject_cast<RegionAndLangSettings *>(settings)) {
+        if (auto *regionandlangkcm = qobject_cast<KCMRegionAndLang *>(kcm)) {
+            m_settings = regionandlangsettings;
+            m_selectedLanguageModel->setRegionAndLangSettings(regionandlangsettings, regionandlangkcm);
+            Q_EMIT exampleChanged();
+        }
     }
 }
 
@@ -174,9 +188,10 @@ void LanguageListModel::setIsPreviewExample(bool preview)
     m_isPreviewExample = preview;
 }
 
-void SelectedLanguageModel::setRegionAndLangSettings(RegionAndLangSettings *settings)
+void SelectedLanguageModel::setRegionAndLangSettings(RegionAndLangSettings *settings, KCMRegionAndLang *kcm)
 {
     m_settings = settings;
+    m_kcm = kcm;
 
     beginResetModel();
     if (m_settings->language().isEmpty() && m_settings->isDefaultSetting(SettingType::Lang)) {
@@ -206,7 +221,7 @@ void SelectedLanguageModel::setRegionAndLangSettings(RegionAndLangSettings *sett
     endResetModel();
 
     // check for invalid lang
-    if (const QString lang = KCMRegionAndLang::toGlibcLocale(m_selectedLanguages.front()); lang.isEmpty()) {
+    if (const QString lang = m_kcm->toGlibcLocale(m_selectedLanguages.front()); lang.isEmpty()) {
         m_unsupportedLanguage = m_selectedLanguages.front();
         Q_EMIT unsupportedLanguageChanged();
     } else if (!m_unsupportedLanguage.isEmpty()) {
@@ -343,7 +358,7 @@ void SelectedLanguageModel::saveLanguages()
         m_settings->config()->group(QStringLiteral("Formats")).deleteEntry("lang");
         m_settings->config()->group(QStringLiteral("Translations")).deleteEntry("language");
     } else {
-        QString lang = KCMRegionAndLang::toGlibcLocale(m_selectedLanguages.front());
+        QString lang = m_kcm->toGlibcLocale(m_selectedLanguages.front());
         if (lang.isEmpty()) {
             m_unsupportedLanguage = m_selectedLanguages.front();
             Q_EMIT unsupportedLanguageChanged();
