@@ -29,9 +29,6 @@
 #include <QX11Info>
 #endif
 
-#include <KPackage/Package>
-#include <KPackage/PackageLoader>
-
 #include <KAuthorized>
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -39,6 +36,7 @@
 #include <KUser>
 #include <KWindowEffects>
 #include <KWindowSystem>
+#include <KX11Extras>
 #include <LayerShellQt/Window>
 
 #include <netwm.h>
@@ -67,7 +65,7 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow *parent, KWorkSpace::ShutdownType sdtype,
     setColor(QColor(Qt::transparent));
     setScreen(screen);
 
-    if (KWindowSystem::isPlatformWayland()) {
+    if (KWindowSystem::isPlatformWayland() && !m_windowed) {
         if (auto w = LayerShellQt::Window::get(this)) {
             w->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityExclusive);
             w->setExclusiveZone(-1);
@@ -151,19 +149,11 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow *parent, KWorkSpace::ShutdownType sdtype,
     engine()->rootContext()->setContextObject(new KLocalizedContext(engine()));
 }
 
-void KSMShutdownDlg::init()
+void KSMShutdownDlg::init(const KPackage::Package &package)
 {
     rootContext()->setContextProperty(QStringLiteral("screenGeometry"), screen()->geometry());
 
-    QString fileName;
-    KPackage::Package package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
-    KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("kdeglobals")), "KDE");
-    const QString packageName = cg.readEntry("LookAndFeelPackage", QString());
-    if (!packageName.isEmpty()) {
-        package.setPath(packageName);
-    }
-
-    fileName = package.filePath("logoutmainscript");
+    const QString fileName = package.filePath("logoutmainscript");
 
     if (QFile::exists(fileName)) {
         setSource(package.fileUrl("logoutmainscript"));
@@ -193,8 +183,12 @@ void KSMShutdownDlg::init()
     // is too early and we don't have the root object yet
     const QColor backgroundColor = rootObject() ? rootObject()->property("backgroundColor").value<QColor>() : QColor();
     KWindowEffects::enableBackgroundContrast(this, true, 0.4, (backgroundColor.value() > 128 ? 1.6 : 0.3), 1.7);
-    KQuickAddons::QuickViewSharedEngine::showFullScreen();
-    setFlag(Qt::FramelessWindowHint);
+    if (m_windowed) {
+        show();
+    } else {
+        showFullScreen();
+        setFlag(Qt::FramelessWindowHint);
+    }
     requestActivate();
 
     KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
@@ -207,7 +201,7 @@ void KSMShutdownDlg::resizeEvent(QResizeEvent *e)
 {
     KQuickAddons::QuickViewSharedEngine::resizeEvent(e);
 
-    if (KWindowSystem::compositingActive()) {
+    if (KX11Extras::compositingActive()) {
         // TODO: reenable window mask when we are without composite?
         //        clearMask();
     } else {
